@@ -4,7 +4,7 @@ from bread.utils import Link, ModelHref, pretty_modelname, reverse
 from bread.views import BrowseView
 from django.utils.translation import gettext_lazy as _
 
-from basxconnect.core.models import Category, RelationshipType, Term
+from basxconnect.core.models import RelationshipType, Term, Vocabulary
 
 R = layout.grid.Row
 C = layout.grid.Col
@@ -35,13 +35,22 @@ def relationshipssettings(request):
                         icon=layout.icon.Icon("add", size=20),
                     ),
                     rowactions=[
+                        Link(
+                            label=_("Edit"),
+                            href=ModelHref(
+                                RelationshipType, "edit", kwargs={"pk": hg.C("row.pk")}
+                            ),
+                            iconname="edit",
+                        ),
                         Link(
                             label=_("Delete"),
                             href=ModelHref(
-                                Term, "delete", kwargs={"pk": hg.C("row.pk")}
+                                RelationshipType,
+                                "delete",
+                                kwargs={"pk": hg.C("row.pk")},
                             ),
                             iconname="trash-can",
-                        )
+                        ),
                     ],
                     backurl=reverse(
                         "basxconnect.core.views.settings_views.relationshipssettings"
@@ -55,49 +64,20 @@ def relationshipssettings(request):
 
 def personsettings(request):
     ret = layout.grid.Grid(R(C(hg.H3(_("Persons")))), gutter=False)
-    for category in Category.objects.all():
+    for vocabulary in Vocabulary.objects.all():
         ret.append(
             R(
-                C(generate_term_datatable(category.name, category.slug)),
+                C(generate_term_datatable(vocabulary.name, vocabulary.slug)),
                 style="margin-bottom: 2rem",
             )
         )
     return ret
 
 
-def generalsettings(request):
-    return hg.BaseElement(
-        R(C(F("name"))),
-        R(C(F("name_addition"))),
-        layout.form.FormsetField.as_plain(
-            "core_postal_list",
-            hg.BaseElement(
-                R(C(F("address"))),
-                R(
-                    C(F("postcode"), breakpoint="sm", width=1),
-                    C(F("city"), breakpoint="sm", width=3),
-                ),
-                R(C(F("country"))),
-            ),
-            can_delete=False,
-            max_num=1,
-            extra=1,
-        ),
-        R(
-            C(single_item_fieldset("core_phone_list", "number")),
-            C(
-                single_item_fieldset(
-                    "core_email_list",
-                    "email",
-                )
-            ),
-        ),
-        R(
-            C(single_item_fieldset("core_web_list", "url")),
-            C(),
-        ),
-        R(C(layout.helpers.SubmitButton(_("Save")))),
-    )
+def maintenancesettings(request):
+    ret = layout.grid.Grid(R(C(hg.H3(_("Maintenance")))), gutter=False)
+    ret.append(R(C(hg.H4(_("Coming soon")))))
+    return ret
 
 
 def single_item_fieldset(related_field, fieldname, queryset=None):
@@ -112,13 +92,13 @@ def single_item_fieldset(related_field, fieldname, queryset=None):
     )
 
 
-def generate_term_datatable(title, category_slug):
+def generate_term_datatable(title, vocabulary_slug):
     """Helper function to display a table for all terms of a certain term, currently always returns to the personsettings view"""
     # TODO: make the backurl dynamic to return to current view (needs correct handling in the DataTable code)
 
-    cat = Category.objects.filter(slug=category_slug).first() or ""
+    cat = Vocabulary.objects.filter(slug=vocabulary_slug).first() or ""
     return layout.datatable.DataTable.from_queryset(
-        Term.objects.filter(category__slug=category_slug),
+        Term.objects.filter(vocabulary__slug=vocabulary_slug),
         columns=["term"],
         title=title,
         primary_button=layout.button.Button.fromlink(
@@ -127,7 +107,7 @@ def generate_term_datatable(title, category_slug):
                     Term,
                     "add",
                     query={
-                        "category": cat.id,
+                        "vocabulary": cat.id,
                         "next": reverse(
                             "basxconnect.core.views.settings_views.personsettings"
                         ),
