@@ -1,10 +1,15 @@
+import datetime
+from datetime import timedelta
+
 import htmlgenerator as hg
 from bread.layout import button
 from django.db import models
+from django.utils import timezone
 from django.utils.translation import gettext_lazy as _
 from django_countries.fields import CountryField
 from phonenumber_field.modelfields import PhoneNumberField
 
+from .. import celery_tasks
 from .persons import Person
 from .utils import Term
 
@@ -16,15 +21,6 @@ class Address(models.Model):
         related_name="%(app_label)s_%(class)s_list",
     )
     person.verbose_name = _("Person")
-    status = models.ForeignKey(
-        Term,
-        on_delete=models.SET_NULL,
-        null=True,
-        blank=True,
-        related_name="status_%(app_label)s_%(class)s_list",
-        limit_choices_to={"vocabulary__slug": "addressstatus"},
-    )
-    status.verbose_name = _("Status")
 
     @classmethod
     def get_contact_related_fieldnames(cls):
@@ -63,7 +59,7 @@ class Email(Address):
     asbutton.verbose_name = _("Email")
 
     def __str__(self):
-        return self.email
+        return str(self.email)
 
     class Meta:
         verbose_name = _("Email address")
@@ -83,7 +79,7 @@ class Web(Address):
     type.verbose_name = _("Type")
 
     def __str__(self):
-        return self.url
+        return str(self.url)
 
     class Meta:
         verbose_name = _("Web address")
@@ -104,7 +100,7 @@ class Phone(Address):
     def __str__(self):
         if self.type:
             return f"{self.number} ({self.type})"
-        return self.number
+        return str(self.number)
 
     class Meta:
         verbose_name = _("Phone number")
@@ -125,7 +121,7 @@ class Fax(Address):
     def __str__(self):
         if self.type:
             return f"{self.number} ({self.type})"
-        return self.number
+        return str(self.number)
 
     class Meta:
         verbose_name = _("Fax number")
@@ -146,6 +142,8 @@ class Postal(Address):
         limit_choices_to={"vocabulary__slug": "addresstype"},
     )
     type.verbose_name = _("Type")
+    valid_from = models.DateField(_("Valid from"), blank=True, null=True)
+    valid_until = models.DateField(_("Valid until"), blank=True, null=True)
 
     def __str__(self):
         ret = [self.address]
@@ -156,6 +154,21 @@ class Postal(Address):
         ret.append(self.country.name)
         return ", ".join(ret)
 
+    def save(
+        self, force_insert=False, force_update=False, using=None, update_fields=None
+    ):
+        super().save(force_insert, force_update, using, update_fields)
+        if self.valid_until and self.valid_until >= timezone.now().date():
+            celery_tasks.save_person.apply_async(
+                (self.person.pk,),
+                eta=datetime.datetime.combine(self.valid_until, datetime.time(0, 0))
+                + timedelta(days=1),
+            )
+
+        # TODO why is this not necessary?
+        # elif self.valid_until and self.valid_until < timezone.now().date():
+        #     self.person.save()
+
     class Meta:
         verbose_name = _("Postal address")
         verbose_name_plural = _("Postal addresses")
