@@ -3,19 +3,29 @@ import random
 
 from bread import layout
 from bread.utils import get_concrete_instance, pretty_modelname
+from bread.utils.inheritancemanager import InheritanceManager
 from django.contrib.contenttypes.fields import GenericRelation
 from django.db import models
+from django.utils import timezone
 from django.utils.translation import gettext_lazy as _
 from languages.fields import LanguageField
 from simple_history.models import HistoricalRecords
 
-from .. import settings
 from .utils import Note, Term
 
 LanguageField.db_collation = None  # fix issue with LanguageField in django 3.2
 
 
-class PersonManager(models.Manager):
+def preferred_languages_choices(field, request, instance):
+    from .. import settings
+
+    return settings.PREFERRED_LANGUAGES
+
+
+class PersonManager(InheritanceManager):
+    def get_queryset(self):
+        return super().get_queryset().select_subclasses()
+
     def trash(self, *args, **kwargs):
         return super().get_queryset(*args, **kwargs).filter(deleted=True)
 
@@ -47,9 +57,7 @@ class Person(models.Model):
     preferred_language = LanguageField(
         _("Preferred Language"), blank=True, max_length=8
     )  # mitigate up-stream bug
-    preferred_language.lazy_choices = (
-        lambda field, request, instance: settings.PREFERRED_LANGUAGES
-    )
+    preferred_language.lazy_choices = preferred_languages_choices
 
     tags = models.ManyToManyField(
         Term,
@@ -103,7 +111,7 @@ class Person(models.Model):
     _type = models.ForeignKey(
         Term, on_delete=models.SET_NULL, null=True, blank=True, related_name="+"
     )
-    _type.verbose_name = _("Person Category")
+    _type.verbose_name = _("Person Type")
 
     objects = PersonManager()
 
@@ -139,11 +147,23 @@ class Person(models.Model):
         if not self._maintype:
             self._maintype = "person"
         if hasattr(self, "core_postal_list"):
-            if (
-                self.core_postal_list.all().count() == 1
+            active_postals = [
+                postal
+                for postal in self.core_postal_list.all()
+                if postal.valid_until is None
+                or postal.valid_until >= timezone.now().date()
+            ]
+            if len(active_postals) == 0:
+                self.primary_postal_address = None
+            elif (
+                len(active_postals) == 1
                 or self.primary_postal_address is None
+                or (
+                    self.primary_postal_address.valid_until
+                    and self.primary_postal_address.valid_until < timezone.now().date()
+                )
             ):
-                self.primary_postal_address = self.core_postal_list.first()
+                self.primary_postal_address = active_postals[0]
         else:
             self.primary_postal_address = None
         if hasattr(self, "core_email_list"):
