@@ -113,7 +113,6 @@ urlpatterns = [
     *default_model_paths(models.Vocabulary),
     *default_model_paths(models.Postal),
     *default_model_paths(models.Phone),
-    *default_model_paths(models.Email),
     *default_model_paths(models.Web),
     autopath(settings_views.generalsettings),
     autopath(
@@ -122,6 +121,7 @@ urlpatterns = [
     ),
     autopath(settings_views.personsettings),
     autopath(settings_views.relationshipssettings),
+    autopath(settings_views.maintenancesettings),
     autopath(search_person_view.searchperson),
     autopath(
         person_modals_views.NaturalPersonEditMailingsView.as_view(),
@@ -151,10 +151,6 @@ urlpatterns = [
         person_modals_views.AddPostalAddressView.as_view(),
         urlname=model_urlname(models.Postal, "ajax_add"),
     ),
-    autopath(
-        person_modals_views.DeletePostalAddressView.as_view(),
-        urlname=model_urlname(models.Postal, "ajax_delete"),
-    ),
     autopath(
         person_modals_views.NaturalPersonEditRemarksView.as_view(),
         urlname=model_urlname(models.NaturalPerson, "ajax_edit_remarks"),
@@ -179,4 +175,16 @@ urlpatterns = [
         person_modals_views.PersonAssociationEditTagsView.as_view(),
         urlname=model_urlname(models.PersonAssociation, "ajax_edit_tags"),
     ),
+    autopath(
+        person_details_views.confirm_delete_email,
+        urlname=model_urlname(models.Email, "delete"),
+    ),
+    autopath(
+        person_modals_views.AddEmailAddressView.as_view(),
+        urlname=model_urlname(models.Email, "add"),
+    ),
+    autopath(
+        person_modals_views.EditEmailAddressView.as_view(),
+        urlname=model_urlname(models.Email, "edit"),
+    ),
 ]
