@@ -14,6 +14,7 @@ from django.utils.html import mark_safe
 from django.utils.translation import gettext_lazy as _
 from django.utils.translation import pgettext_lazy
 
+import basxconnect.core.layouts.editperson.common.base_data
 from basxconnect.core import models, settings
 
 
@@ -42,7 +43,13 @@ def export(request, queryset):
             tags = set(form.cleaned_data.get("tags"))
 
             def render_matching_tags(context):
-                return ", ".join(str(i) for i in tags & set(context["row"].tags.all()))
+                return ", ".join(
+                    str(i)
+                    for i in tags
+                    & set(
+                        basxconnect.core.layouts.editperson.common.base_data.tags.all()
+                    )
+                )
 
             columns.append(
                 DataTableColumn(
@@ -87,7 +94,9 @@ class PersonBrowseView(BrowseView):
             "personnumber__int",
         ),
         "status",
-        DataTableColumn(_("Person Category"), hg.C("row._type"), "_type"),
+        DataTableColumn(
+            layout.fieldlabel(models.Person, "_type"), hg.C("row._type"), "_type"
+        ),
         DataTableColumn(
             layout.fieldlabel(models.Person, "name"),
             hg.DIV(
@@ -139,6 +148,7 @@ class PersonBrowseView(BrowseView):
         url=reverse("basxconnect.core.views.person.search_person_view.searchperson")
     )
     rowclickaction = BrowseView.gen_rowclickaction("read")
+    viewstate_sessionkey = "personbrowseview"
 
     class FilterForm(forms.Form):
         naturalperson = forms.BooleanField(required=False, label=_("Natural Person"))
@@ -187,20 +197,22 @@ class PersonBrowseView(BrowseView):
                 == "bx--toolbar-content"
             )
         )[0]
+        nfilters = self._checkbox_count()
         toolbar.insert(
             -2,
             hg.DIV(
-                hg.SPAN(self._checkbox_count(), id=self.checkboxcounterid),
+                hg.SPAN(nfilters, id=self.checkboxcounterid),
                 layout.icon.Icon(
                     "close",
                     focusable="false",
                     size=15,
                     role="img",
-                    onclick=f"document.location = '{self.request.path}'",
+                    onclick=f"document.location = '{self.request.path}?reset=1'",
                 ),
                 role="button",
                 _class="bx--list-box__selection bx--list-box__selection--multi bx--tag--filter",
-                style="margin: auto 0.5rem;",
+                style="margin: auto 0.5rem;"
+                + (" display: none;" if nfilters == 0 else ""),
                 tabindex="0",
                 title=("Reset"),
             ),
@@ -222,7 +234,9 @@ class PersonBrowseView(BrowseView):
             counter += form.cleaned_data["personassociation_subtypes"].count()
             counter += form.cleaned_data["tags"].count()
             counter += len(form.cleaned_data["preferred_language"])
-            counter += len(form.cleaned_data["status"])
+            counter += (
+                1 if "inactive" in form.cleaned_data["status"] else 0
+            )  # don't count the "active" checkbox, it is a permanent default
             counter += 1 if form.cleaned_data["trash"] else 0
         return counter
 
@@ -230,9 +244,15 @@ class PersonBrowseView(BrowseView):
         form = self._filterform()
         if form.is_valid():
             ret = (
-                super()
-                .get_queryset()
-                .filter(deleted=form.cleaned_data.get("trash", False))
+                (
+                    super()
+                    .get_queryset()
+                    .filter(deleted=form.cleaned_data.get("trash", False))
+                )
+                .select_related(
+                    "primary_email_address", "primary_postal_address", "_type"
+                )
+                .prefetch_related("tags")
             )
             if any(
                 [
@@ -291,7 +311,7 @@ class PersonBrowseView(BrowseView):
                 self._filterform(),
                 hg.DIV(
                     hg.DIV(
-                        hg.DIV(layout.helpers.Label(_("Tags"))),
+                        hg.DIV(layout.helpers.Label(_("Person Type"))),
                         hg.DIV(
                             hg.DIV(
                                 hg.DIV(
@@ -385,7 +405,11 @@ class PersonBrowseView(BrowseView):
                         onclick="this.parentElement.parentElement.parentElement.parentElement.parentElement.style.display = 'none'",
                     ),
                     layout.button.Button.fromlink(
-                        Link(label=_("Reset"), href=self.request.path, iconname=None),
+                        Link(
+                            label=_("Reset"),
+                            href=self.request.path + "?reset=1",
+                            iconname=None,
+                        ),
                         buttontype="secondary",
                     ),
                     layout.button.Button(
@@ -411,12 +435,15 @@ class PersonBrowseView(BrowseView):
                     function updateCheckboxCounter(group) {
                         var items = $$('input[type=checkbox]', group);
                         var count = 0;
-                        for(item of items)
-                            count += item.getAttribute('aria-checked') == 'true' ? 1 : 0
+                        for(item of items) {
+                            if(!(item.name === 'status' && item.value === 'active'))
+                                count += item.getAttribute('aria-checked') == 'true' ? 1 : 0
+                        }
                         $('#%s').innerHTML = count;
+                        $('#%s').closest('div[role=button]').style.display = count === 0 ? "none" : "flex";
                     }
                     """
-                    % (self.checkboxcounterid,)
+                    % (self.checkboxcounterid, self.checkboxcounterid)
                 )
             ),
             style="background-color: #fff",
