@@ -2,8 +2,7 @@ import django.forms
 import htmlgenerator as hg
 from bread import layout
 from bread.layout.components.icon import Icon
-from bread.views import AddView, DeleteView, EditView
-from django.shortcuts import get_object_or_404
+from bread.views import AddView, EditView
 from django.utils.translation import gettext_lazy as _
 
 from basxconnect.core import models
@@ -118,7 +117,15 @@ class LegalPersonEditMailingsView(EditView):
 
 class EditPostalAddressView(EditView):
     model = models.Postal
-    fields = ["type", "address", "postcode", "city", "country"]
+    fields = [
+        "type",
+        "address",
+        "postcode",
+        "city",
+        "country",
+        "valid_from",
+        "valid_until",
+    ]
 
     def form_valid(self, form, *args, **kwargs):
         ret = super().form_valid(form, *args, **kwargs)
@@ -153,20 +160,55 @@ class EditPostalAddressView(EditView):
 class AddPostalAddressView(AddView):
     model = models.Postal
 
-    def post(self, request, *args, **kwargs):
-        ret = super().post(request, *args, **kwargs)
+    def form_valid(self, request, *args, **kwargs):
+        ret = super().form_valid(request, *args, **kwargs)
         self.object.person.save()
         return ret
 
 
-class DeletePostalAddressView(DeleteView):
-    model = models.Postal
+class EditEmailAddressView(EditView):
+    model = models.Email
+    fields = ["type", "email"]
 
-    def get(self, *args, **kwargs):
-        person = get_object_or_404(self.model, pk=self.kwargs.get("pk")).person
-        ret = super().get(*args, **kwargs)
-        person.refresh_from_db()
-        person.save()
+    def form_valid(self, form, *args, **kwargs):
+        ret = super().form_valid(form, *args, **kwargs)
+        is_primary = form.cleaned_data["is_primary"]
+        if is_primary:
+            self.object.person.primary_email_address = self.object
+        self.object.person.save()
+        return ret
+
+    def get_form_class(self, *args, **kwargs):
+        class EditEmailForm(super().get_form_class(*args, **kwargs)):
+            is_primary = django.forms.BooleanField(
+                label=_("Use as primary email address"), required=False
+            )
+
+        return EditEmailForm
+
+    def get_layout(self):
+        form_fields = [layout.form.FormField(field) for field in [*self.fields]] + [
+            hg.If(
+                hg.F(
+                    lambda c: c["object"].person.primary_email_address
+                    and c["object"].person.primary_email_address.pk != c["object"].pk
+                ),
+                layout.form.FormField("is_primary"),
+                "",
+            )
+        ]
+        return hg.BaseElement(
+            hg.H3(_("Edit Email")),
+            layout.form.Form.wrap_with_form(hg.C("form"), hg.DIV(*form_fields)),
+        )
+
+
+class AddEmailAddressView(AddView):
+    model = models.Email
+
+    def post(self, request, *args, **kwargs):
+        ret = super().post(request, *args, **kwargs)
+        self.object.person.save()
         return ret
 
 
