@@ -1,8 +1,11 @@
 from django.db import models
 from django.utils.translation import gettext_lazy as _
+from languages.fields import LanguageField
 
 from basxconnect.core.models import Email
 
+LanguageField.db_collation = None  # fix issue with LanguageField in django 3.2
+
 
 class Interest(models.Model):
     name = models.CharField(max_length=100, unique=True)
@@ -12,6 +15,12 @@ class Interest(models.Model):
         return self.name
 
 
+def languages_choices(field, request, instance):
+    from basxconnect.core import settings
+
+    return settings.PREFERRED_LANGUAGES
+
+
 class MailingPreferences(models.Model):
     email = models.OneToOneField(Email, on_delete=models.CASCADE)
     status = models.CharField(
@@ -26,3 +35,8 @@ class MailingPreferences(models.Model):
 
     interests = models.ManyToManyField(Interest, blank=True)
     interests.verbose_name = _("Mailing Interests")
+
+    language = LanguageField(
+        _("Language"), blank=True, max_length=8
+    )  # mitigate up-stream bug
+    language.lazy_choices = languages_choices
